@@ -4,19 +4,17 @@ package Test::Class::Moose;
 
 use 5.10.0;
 
-our $VERSION = '0.82';
+our $VERSION = '0.83';
 
 use Moose 2.0000;
 use Carp;
 use namespace::autoclean;
 use Import::Into;
 use Sub::Attribute;
-use Test::Most ();
 
-# We don't use anything from these two modules, but we want to specify a
-# specific prereq version.
-use Test2 1.302059      ();
-use Test::More 1.302059 ();
+# We don't use anything from this module, but we want to specify a specific
+# prereq version.
+use Test2 1.302059 ();
 
 use Test::Class::Moose::AttributeRegistry;
 use Test::Class::Moose::Config;
@@ -151,8 +149,10 @@ sub import {
       warnings
     );
 
-    push @imports, 'Test::Most'
-      unless $args{bare};
+    unless ( $args{bare} ) {
+        require Test::Most;
+        push @imports, 'Test::Most';
+    }
 
     $_->import::into($caller) for @imports;
 
@@ -222,7 +222,7 @@ Test::Class::Moose - Serious testing for serious Perl
 
 =head1 VERSION
 
-version 0.82
+version 0.83
 
 =head1 SYNOPSIS
 
